window.Gleam.initSearch([{"doc":"lamb","title":"lamb","content":"# lamb\n\n[![Package Version](https://img.shields.io/hexpm/v/lamb)](https://hex.pm/packages/lamb)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lamb/)\n\nA gleam library for operating and querying ETS tables.\n\n```gleam\nimport lamb.{Set, Private}\nimport lamb/query\nimport lamb/query/term as t\n\ntype User {\n  User(name: String, age: Int, bio: String)\n}\n\npub fn main() {\n  // Create a table and insert 5 records.\n  let assert Ok(table) = lamb.create(&quot;users&quot;, Private, Set, False)\n\n  lamb.insert(table, 1, User(&quot;Raúl&quot;, age: 35, bio: &quot;While at friends gatherings, plays yugioh.&quot;))\n  lamb.insert(table, 2, User(&quot;César&quot;, age: 33, bio: &quot;While outdoors, likes bird watching.&quot;))\n  lamb.insert(table, 3, User(&quot;Carlos&quot;, age: 30, bio: &quot;Always craving for coffee.&quot;))\n  lamb.insert(table, 4, User(&quot;Adrián&quot;, age: 26, bio: &quot;Simply exists.&quot;))\n\n  // Retrieve all User records.\n  let _records = lamb.search(table, query.new())\n\n  // Retrieve all User ids.\n  let to_index = fn(index, _record) { index }\n  \n  let query =\n    query.new()\n    |&gt; query.index(t.v(0))\n    |&gt; query.map(to_index)\n\n  let _ids = lamb.all(table, query)\n\n  // Retrieve all User records in batches of 2.\n  let assert Records([_, _], step) = lamb.batch(table, by: 2, where: q.new())\n  let assert Records([_, _], step) = lamb.continue(step)\n  let assert End([]) = lamb.continue(step)\n}\n```\n\nThe API does rely on matchspecs to query stored data, in [erlang matchspecs](https://www.erlang.org/doc/apps/erts/match_spec.html) are composed by a Tuple of arity 3 called a `MatchFunction`:\n\n- A `Head` that contains the shape of the data we want to match to, as well as variable declarations.\n- A list of `Condition` expressions that can help filter data through predicates.\n- A `Body` that declares the shape and variables we&#39;d like to output from the `MatchFunction`.\n\nNone of the current operations enforce types, querying so far is a &quot;dynamic&quot; operation.\n","url":"index.html"},{"doc":"lamb/query/term","title":"any","content":"pub fn any() -&gt; Atom\n\nSynonyms:\nlamb/query/term.any\nlamb/query/term any","url":"lamb/query/term.html#any"},{"doc":"lamb/query/term","title":"records","content":"pub fn records() -&gt; Atom\n\nSynonyms:\nlamb/query/term.records\nlamb/query/term records","url":"lamb/query/term.html#records"},{"doc":"lamb/query/term","title":"tag","content":"pub fn tag(name: String) -&gt; Atom\n\nSynonyms:\nlamb/query/term.tag\nlamb/query/term tag","url":"lamb/query/term.html#tag"},{"doc":"lamb/query/term","title":"var","content":"pub fn var(position: Int) -&gt; Atom\n\nSynonyms:\nlamb/query/term.var\nlamb/query/term var","url":"lamb/query/term.html#var"},{"doc":"lamb/query/term","title":"vars","content":"pub fn vars() -&gt; Atom\n\nSynonyms:\nlamb/query/term.vars\nlamb/query/term vars","url":"lamb/query/term.html#vars"},{"doc":"lamb/query/term","title":"lamb/query/term","content":"","url":"lamb/query/term.html"},{"doc":"lamb/query","title":"Query","content":"pub type Query(index, record, x) =\n  #(Head(index, record), Conditions, Body(x))\n\n\nSynonyms:\nlamb/query.Query\nlamb/query Query","url":"lamb/query.html#Query"},{"doc":"lamb/query","title":"index","content":"pub fn index(\n  query: #(#(a, b), List(Nil), List(c)),\n  matches spec: d,\n) -&gt; #(#(d, b), List(Nil), List(c))\n\nSynonyms:\nlamb/query.index\nlamb/query index","url":"lamb/query.html#index"},{"doc":"lamb/query","title":"map","content":"pub fn map(\n  query: #(#(a, b), List(Nil), List(c)),\n  into mapper: fn(a, b) -&gt; d,\n) -&gt; #(#(a, b), List(Nil), List(d))\n\nSynonyms:\nlamb/query.map\nlamb/query map","url":"lamb/query.html#map"},{"doc":"lamb/query","title":"new","content":"pub fn new() -&gt; #(#(Atom, Atom), List(Nil), List(Atom))\n\nSynonyms:\nlamb/query.new\nlamb/query new","url":"lamb/query.html#new"},{"doc":"lamb/query","title":"record","content":"pub fn record(\n  query: #(#(a, b), List(Nil), List(c)),\n  matches spec: d,\n) -&gt; #(#(a, d), List(Nil), List(c))\n\nSynonyms:\nlamb/query.record\nlamb/query record","url":"lamb/query.html#record"},{"doc":"lamb/query","title":"validate","content":"pub fn validate(\n  query: #(#(a, b), List(Nil), List(c)),\n) -&gt; Result(#(#(a, b), List(Nil), List(c)), List(String))\n\nSynonyms:\nlamb/query.validate\nlamb/query validate","url":"lamb/query.html#validate"},{"doc":"lamb/query","title":"lamb/query","content":"","url":"lamb/query.html"},{"doc":"lamb","title":"Access","content":"pub type Access {\n  Public\n  Protected\n  Private\n}\n\nPublic\n\n\nProtected\n\n\nPrivate\n\n\nSynonyms:\nlamb.Access\nlamb Access","url":"lamb.html#Access"},{"doc":"lamb","title":"Error","content":"pub type Error {\n  AlreadyRegistered(Name)\n}\n\nAlreadyRegistered(Name)\n\n\nSynonyms:\nlamb.Error\nlamb Error","url":"lamb.html#Error"},{"doc":"lamb","title":"Kind","content":"pub type Kind {\n  Set\n  Bag\n}\n\nSet\n\n\nBag\n\n\nSynonyms:\nlamb.Kind\nlamb Kind","url":"lamb.html#Kind"},{"doc":"lamb","title":"Partial","content":"pub type Partial(record) {\n  Records(List(record), Step)\n  End(List(record))\n}\n\nRecords(List(record), Step)\n\n\nEnd(List(record))\n\n\nSynonyms:\nlamb.Partial\nlamb Partial","url":"lamb.html#Partial"},{"doc":"lamb","title":"Step","content":"pub type Step\n\n\nSynonyms:\nlamb.Step\nlamb Step","url":"lamb.html#Step"},{"doc":"lamb","title":"Table","content":"pub type Table(index, record) {\n  Table(\n    reference: TableId,\n    name: Name,\n    kind: Kind,\n    access: Access,\n    registered: Bool,\n  )\n}\n\nTable(\n  reference: TableId,\n  name: Name,\n  kind: Kind,\n  access: Access,\n  registered: Bool,\n)\n\n\nSynonyms:\nlamb.Table\nlamb Table","url":"lamb.html#Table"},{"doc":"lamb","title":"batch","content":"pub fn batch(\n  from table: Table(a, b),\n  by limit: Int,\n  where query: #(#(c, d), List(Nil), List(e)),\n) -&gt; Partial(f)\n\nSynonyms:\nlamb.batch\nlamb batch","url":"lamb.html#batch"},{"doc":"lamb","title":"continue","content":"pub fn continue(step: Step) -&gt; Partial(a)\n\nSynonyms:\nlamb.continue\nlamb continue","url":"lamb.html#continue"},{"doc":"lamb","title":"count","content":"pub fn count(\n  from table: Table(a, b),\n  where query: #(#(c, d), List(Nil), List(e)),\n) -&gt; Int\n\nSynonyms:\nlamb.count\nlamb count","url":"lamb.html#count"},{"doc":"lamb","title":"create","content":"pub fn create(\n  name name: String,\n  access access: Access,\n  kind kind: Kind,\n  registered registered: Bool,\n) -&gt; Result(Table(a, b), Error)\n\nSynonyms:\nlamb.create\nlamb create","url":"lamb.html#create"},{"doc":"lamb","title":"delete","content":"pub fn delete(table: Table(a, b)) -&gt; Nil\n\nSynonyms:\nlamb.delete\nlamb delete","url":"lamb.html#delete"},{"doc":"lamb","title":"from_name","content":"pub fn from_name(name: String) -&gt; Result(Table(a, b), Nil)\n\nSynonyms:\nlamb.from_name\nlamb from_name","url":"lamb.html#from_name"},{"doc":"lamb","title":"insert","content":"pub fn insert(table: Table(a, b), index: a, record: b) -&gt; Nil\n\nSynonyms:\nlamb.insert\nlamb insert","url":"lamb.html#insert"},{"doc":"lamb","title":"is_alive","content":"pub fn is_alive(table: Table(a, b)) -&gt; Bool\n\nSynonyms:\nlamb.is_alive\nlamb is_alive","url":"lamb.html#is_alive"},{"doc":"lamb","title":"remove","content":"pub fn remove(\n  table: Table(a, b),\n  where query: #(#(c, d), List(Nil), List(e)),\n) -&gt; Int\n\nSynonyms:\nlamb.remove\nlamb remove","url":"lamb.html#remove"},{"doc":"lamb","title":"search","content":"pub fn search(\n  from table: Table(a, b),\n  where query: #(#(c, d), List(Nil), List(e)),\n) -&gt; List(f)\n\nSynonyms:\nlamb.search\nlamb search","url":"lamb.html#search"},{"doc":"lamb","title":"lamb","content":"","url":"lamb.html"}]);